# Support resources

We have an active [Gitter](https://gitter.im/GMLC-TDC/HELICS) channel.

Our [ReadTheDocs](https://helics.readthedocs.io/en/latest/) pages provides a rich set of [documentation](https://helics.readthedocs.io/en/latest/) including a set of introductory [examples](https://helics.readthedocs.io/en/latest/introduction/), a [developers guide](https://helics.readthedocs.io/en/latest/developer-guide/), and complete doxygen-auto-produced [API documentation](https://helics.readthedocs.io/en/latest/doxygen/). There is a [WIKI](https://github.com/GMLC-TDC/HELICS/wiki) with some additional information, and a [USER GUIDE](https://helics.readthedocs.io/en/latest/user-guide/) to help you get started.

We've created a series of roughly 10-minute mini-tutorial videos that discuss various design topics, concepts, and interfaces, including how to use the tool. They can be found on our [YouTube channel](https://www.youtube.com/channel/UCPa81c4BVXEYXt2EShTzbcg).
